@@ -1,19 +1,18 @@
-from jija_orm.executors import templates
-from jija_orm.executors import executors
+from jija_orm.executors import operators, executors
 
 
 class QueryManager:
-    def __init__(self, model_class, class_templates=None):
+    def __init__(self, model_class, class_operators=None):
         self.__model_class = model_class
-        self.__templates = self.fix_templates(class_templates)
+        self.__operators = self.fix_operators(class_operators)
 
     def __add_templates(self, *new_templates) -> 'QueryManager':
-        class_templates = self.__templates.copy()
-        class_templates.extend(new_templates)
-        return self.__class__(self.__model_class, class_templates)
+        class_operators = self.__operators.copy()
+        class_operators.extend(new_templates)
+        return self.__class__(self.__model_class, class_operators)
 
     @staticmethod
-    def fix_templates(class_templates):
+    def fix_operators(class_templates):
         if not class_templates:
             return []
 
@@ -36,35 +35,35 @@ class QueryManager:
 
     @property
     def templates(self):
-        return self.__templates
+        return self.__operators
 
     def select(self, *args, **kwargs) -> 'QueryManager':
-        return self.__add_templates(templates.Select(*args, **kwargs))
+        return self.__add_templates(operators.Select(*args, **kwargs))
 
-    def update(self, *args, **kwargs) -> 'QueryManager':
-        return self.__add_templates(templates.Update(*args, **kwargs))
+    def update(self, **kwargs) -> 'QueryManager':
+        return self.__add_templates(operators.Update(**kwargs))
 
     def insert(self, **kwargs) -> 'QueryManager':
-        return self.__add_templates(templates.Insert(**kwargs))
+        return self.__add_templates(operators.Insert(**kwargs))
 
     def multiple_insert(self, rows) -> 'QueryManager':
-        return self.__add_templates(templates.MultipleInsert(rows))
+        return self.__add_templates(operators.MultipleInsert(rows))
 
     def delete(self):
-        return self.__add_templates(templates.Delete())
+        return self.__add_templates(operators.Delete())
 
     def where(self, *args, **kwargs) -> 'QueryManager':
-        if self.__templates:
-            new_templates = []
+        if self.__operators:
+            new_operators = []
         else:
-            new_templates = [templates.Select()]
+            new_operators = [operators.Select()]
 
-        new_templates.append(templates.Where(*args, **kwargs))
-        return self.__add_templates(*new_templates)
+        new_operators.append(operators.Where(*args, **kwargs))
+        return self.__add_templates(*new_operators)
 
     def __await__(self):
         async def wrapper():
-            executor = executors.Executor(self.__model_class, *self.__templates)
+            executor = executors.Executor(self.__model_class, *self.__operators)
             return await executor.execute()
 
         return wrapper().__await__()
