@@ -5,7 +5,7 @@ import aiofile
 
 from jija_orm.migrator import selectors
 from jija_orm import config, fields
-from jija_orm.utils import NotSet
+from jija_orm import utils
 
 
 class Action:
@@ -289,7 +289,9 @@ class AppMigration:
         migration_dir = config.JijaORM.get_migrations_dir(self.app)
         migration_id, constructor = Migration.get_constructor(self.migrations)
 
-        async with aiofile.async_open(migration_dir.replace('.', '/') + f'/{migration_id}.py', 'w') as file:
+        path = migration_dir.replace('.', '/') + f'/{migration_id}.py'
+        async with aiofile.async_open(path, 'w') as file:
+            print(f'Creating migration manifest {path}')
             await file.write(constructor)
 
     def __repr__(self):
@@ -319,7 +321,6 @@ class ModelMigration(__BaseMigrator):
             childes.append(ConstraintMigration.from_field(constraint_name, raw_constraints[constraint_name]))
 
         return childes
-        # return list(map(lambda field_name: FieldMigration.from_field(field_name, raw_fields[field_name]), raw_fields))
 
     @classmethod
     async def from_table(cls, table):
@@ -361,7 +362,6 @@ class ModelMigration(__BaseMigrator):
     async def execute(self):
         query = self.get_query()
 
-        print(query)
         connection = await config.JijaORM.get_connection()
         await connection.execute(query)
 
@@ -418,7 +418,7 @@ class FieldMigration(__BaseMigrator):
                     AttributeMigration('type', field.get_type()),
                 ]
 
-            if field.default is not NotSet:
+            if field.default is not utils.NotSet:
                 childes.append(AttributeMigration('default', field.default))
 
             return cls(name, Action.CREATE, childes)
@@ -646,8 +646,8 @@ class ConstraintAttributeMigration(__BaseAttributeMigration):
     }
 
     ATTRS_TRANSLATOR = {
-        'field': 'foreign key ({})',
-        'relation_to': 'references {}(id)',
+        'field': 'foreign key ("{}")',
+        'relation_to': 'references "{}"(id)',
         'on_delete': 'on delete {}'
     }
 
